@@ -3,20 +3,28 @@ import warnings
 import numpy as np
 import pytest
 from scipy import linalg
+
+from sklearn import datasets, linear_model
 from sklearn.base import clone
+from sklearn.exceptions import ConvergenceWarning
+from sklearn.linear_model import (
+    Lars,
+    LarsCV,
+    LassoLars,
+    LassoLarsCV,
+    LassoLarsIC,
+    lars_path,
+)
+from sklearn.linear_model._least_angle import _lars_path_residues
 from sklearn.model_selection import train_test_split
 from sklearn.pipeline import make_pipeline
 from sklearn.preprocessing import StandardScaler
-from sklearn.utils._testing import assert_allclose
-from sklearn.utils._testing import assert_array_almost_equal
-from sklearn.utils._testing import ignore_warnings
-from sklearn.utils._testing import TempMemmap
-from sklearn.utils import check_random_state
-from sklearn.exceptions import ConvergenceWarning
-from sklearn import linear_model, datasets
-from sklearn.linear_model._least_angle import _lars_path_residues
-from sklearn.linear_model import LassoLarsIC, lars_path
-from sklearn.linear_model import Lars, LassoLars, LarsCV, LassoLarsCV
+from sklearn.utils._testing import (
+    TempMemmap,
+    assert_allclose,
+    assert_array_almost_equal,
+    ignore_warnings,
+)
 
 # TODO: use another dataset that has multiple drops
 diabetes = datasets.load_diabetes()
@@ -25,42 +33,13 @@ G = np.dot(X.T, X)
 Xy = np.dot(X.T, y)
 n_samples = y.size
 
-# FIXME: 'normalize' to be removed in 1.4
-filterwarnings_normalize = pytest.mark.filterwarnings(
-    "ignore:The default of 'normalize'"
-)
-
-
-# FIXME: 'normalize' to be removed in 1.4
-@pytest.mark.parametrize(
-    "LeastAngleModel", [Lars, LassoLars, LarsCV, LassoLarsCV, LassoLarsIC]
-)
-@pytest.mark.parametrize(
-    "normalize, n_warnings", [(True, 0), (False, 0), ("deprecated", 1)]
-)
-def test_assure_warning_when_normalize(LeastAngleModel, normalize, n_warnings):
-    # check that we issue a FutureWarning when normalize was set
-    rng = check_random_state(0)
-    n_samples = 200
-    n_features = 2
-    X = rng.randn(n_samples, n_features)
-    X[X < 0.1] = 0.0
-    y = rng.rand(n_samples)
-
-    model = LeastAngleModel(normalize=normalize)
-    with warnings.catch_warnings(record=True) as rec:
-        warnings.simplefilter("always", FutureWarning)
-        model.fit(X, y)
-
-    assert len([w.message for w in rec]) == n_warnings
-
 
 def test_simple():
     # Principle of Lars is to keep covariances tied and decreasing
 
     # also test verbose output
-    from io import StringIO
     import sys
+    from io import StringIO
 
     old_stdout = sys.stdout
     try:
@@ -123,7 +102,7 @@ def test_lars_path_gram_equivalent(method, return_path):
 def test_x_none_gram_none_raises_value_error():
     # Test that lars_path with no X and Gram raises exception
     Xy = np.dot(X.T, y)
-    with pytest.raises(ValueError):
+    with pytest.raises(ValueError, match="X and Gram cannot both be unspecified"):
         linear_model.lars_path(None, y, Gram=None, Xy=Xy)
 
 
@@ -138,8 +117,6 @@ def test_all_precomputed():
             assert_array_almost_equal(expected, got)
 
 
-# FIXME: 'normalize' to be removed in 1.4
-@filterwarnings_normalize
 @pytest.mark.filterwarnings("ignore: `rcond` parameter will change")
 # numpy deprecation
 def test_lars_lstsq():
@@ -228,7 +205,6 @@ def test_no_path_all_precomputed():
     assert alpha_ == alphas_[-1]
 
 
-@filterwarnings_normalize
 @pytest.mark.parametrize(
     "classifier", [linear_model.Lars, linear_model.LarsCV, linear_model.LassoLarsIC]
 )
@@ -252,7 +228,6 @@ def test_singular_matrix():
     assert_array_almost_equal(coef_path.T, [[0, 0], [1, 0]])
 
 
-@filterwarnings_normalize
 def test_rank_deficient_design():
     # consistency test that checks that LARS Lasso is handling rank
     # deficient input data (with n_features < rank) in the same way
@@ -261,7 +236,7 @@ def test_rank_deficient_design():
     for X in ([[5, 0], [0, 5], [10, 10]], [[10, 10, 0], [1e-32, 0, 0], [0, 0, 1]]):
         # To be able to use the coefs to compute the objective function,
         # we need to turn off normalization
-        lars = linear_model.LassoLars(0.1, normalize=False)
+        lars = linear_model.LassoLars(0.1)
         coef_lars_ = lars.fit(X, y).coef_
         obj_lars = 1.0 / (2.0 * 3.0) * linalg.norm(
             y - np.dot(X, coef_lars_)
@@ -274,7 +249,6 @@ def test_rank_deficient_design():
         assert obj_lars < obj_cd * (1.0 + 1e-8)
 
 
-@filterwarnings_normalize
 def test_lasso_lars_vs_lasso_cd():
     # Test that LassoLars and Lasso using coordinate descent give the
     # same results.
@@ -292,7 +266,7 @@ def test_lasso_lars_vs_lasso_cd():
 
     # similar test, with the classifiers
     for alpha in np.linspace(1e-2, 1 - 1e-2, 20):
-        clf1 = linear_model.LassoLars(alpha=alpha, normalize=False).fit(X, y)
+        clf1 = linear_model.LassoLars(alpha=alpha).fit(X, y)
         clf2 = linear_model.Lasso(alpha=alpha, tol=1e-8).fit(X, y)
         err = linalg.norm(clf1.coef_ - clf2.coef_)
         assert err < 1e-3
@@ -312,7 +286,6 @@ def test_lasso_lars_vs_lasso_cd():
         assert error < 0.01
 
 
-@filterwarnings_normalize
 def test_lasso_lars_vs_lasso_cd_early_stopping():
     # Test that LassoLars and Lasso using coordinate descent give the
     # same results when early stopping is used.
@@ -346,7 +319,6 @@ def test_lasso_lars_vs_lasso_cd_early_stopping():
         assert error < 0.01
 
 
-@filterwarnings_normalize
 def test_lasso_lars_path_length():
     # Test that the path length of the LassoLars is right
     lasso = linear_model.LassoLars()
@@ -387,7 +359,6 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned():
     assert_array_almost_equal(lars_coef, lasso_coef2, decimal=1)
 
 
-@filterwarnings_normalize
 def test_lasso_lars_vs_lasso_cd_ill_conditioned2():
     # Create an ill-conditioned situation in which the LARS has to go
     # far in the path to converge, and check that LARS and coordinate
@@ -404,7 +375,7 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned2():
             y - np.dot(X, coef)
         ) ** 2 + alpha * linalg.norm(coef, 1)
 
-    lars = linear_model.LassoLars(alpha=alpha, normalize=False)
+    lars = linear_model.LassoLars(alpha=alpha)
     warning_message = "Regressors in active set degenerate."
     with pytest.warns(ConvergenceWarning, match=warning_message):
         lars.fit(X, y)
@@ -418,7 +389,6 @@ def test_lasso_lars_vs_lasso_cd_ill_conditioned2():
     assert lars_obj < cd_obj * (1.0 + 1e-8)
 
 
-@filterwarnings_normalize
 def test_lars_add_features():
     # assure that at least some features get added if necessary
     # test for 6d2b4c
@@ -429,7 +399,6 @@ def test_lars_add_features():
     assert np.all(np.isfinite(clf.coef_))
 
 
-@filterwarnings_normalize
 def test_lars_n_nonzero_coefs(verbose=False):
     lars = linear_model.Lars(n_nonzero_coefs=6, verbose=verbose)
     lars.fit(X, y)
@@ -439,7 +408,6 @@ def test_lars_n_nonzero_coefs(verbose=False):
     assert len(lars.alphas_) == 7
 
 
-@filterwarnings_normalize
 @ignore_warnings
 def test_multitarget():
     # Assure that estimators receiving multidimensional y do the right thing
@@ -472,7 +440,6 @@ def test_multitarget():
             assert_array_almost_equal(Y_pred[:, k], y_pred)
 
 
-@filterwarnings_normalize
 def test_lars_cv():
     # Test the LassoLarsCV object by checking that the optimal alpha
     # increases as the number of samples increases.
@@ -489,7 +456,6 @@ def test_lars_cv():
     assert not hasattr(lars_cv, "n_nonzero_coefs")
 
 
-@filterwarnings_normalize
 def test_lars_cv_max_iter(recwarn):
     warnings.simplefilter("always")
     with np.errstate(divide="raise", invalid="raise"):
@@ -499,20 +465,18 @@ def test_lars_cv_max_iter(recwarn):
         x = rng.randn(len(y))
         X = diabetes.data
         X = np.c_[X, x, x]  # add correlated features
+        X = StandardScaler().fit_transform(X)
         lars_cv = linear_model.LassoLarsCV(max_iter=5, cv=5)
         lars_cv.fit(X, y)
+
     # Check that there is no warning in general and no ConvergenceWarning
     # in particular.
     # Materialize the string representation of the warning to get a more
     # informative error message in case of AssertionError.
     recorded_warnings = [str(w) for w in recwarn]
-    # FIXME: when 'normalize' is removed set exchange below for:
-    # assert len(recorded_warnings) == []
-    assert len(recorded_warnings) == 1
-    assert "normalize' will be set to False in version 1.2" in recorded_warnings[0]
+    assert len(recorded_warnings) == 0
 
 
-@filterwarnings_normalize
 def test_lasso_lars_ic():
     # Test the LassoLarsIC object by checking that
     # - some good features are selected.
@@ -523,6 +487,7 @@ def test_lasso_lars_ic():
     rng = np.random.RandomState(42)
     X = diabetes.data
     X = np.c_[X, rng.randn(X.shape[0], 5)]  # add 5 bad features
+    X = StandardScaler().fit_transform(X)
     lars_bic.fit(X, y)
     lars_aic.fit(X, y)
     nonzero_bic = np.where(lars_bic.coef_)[0]
@@ -531,12 +496,6 @@ def test_lasso_lars_ic():
     assert len(nonzero_bic) < len(nonzero_aic)
     assert np.max(nonzero_bic) < diabetes.data.shape[1]
 
-    # test error on unknown IC
-    lars_broken = linear_model.LassoLarsIC("<unknown>")
-
-    with pytest.raises(ValueError):
-        lars_broken.fit(X, y)
-
 
 def test_lars_path_readonly_data():
     # When using automated memory mapping on large input, the
@@ -588,7 +547,6 @@ estimator_parameter_map = {
 }
 
 
-@filterwarnings_normalize
 def test_estimatorclasses_positive_constraint():
     # testing the transmissibility for the positive option of all estimator
     # classes in this same function here
@@ -610,7 +568,6 @@ def test_estimatorclasses_positive_constraint():
         assert min(estimator.coef_) >= 0
 
 
-@filterwarnings_normalize
 def test_lasso_lars_vs_lasso_cd_positive():
     # Test that LassoLars and Lasso using coordinate descent give the
     # same results when using the positive option
@@ -643,7 +600,7 @@ def test_lasso_lars_vs_lasso_cd_positive():
 
     for alpha in np.linspace(6e-1, 1 - 1e-2, 20):
         clf1 = linear_model.LassoLars(
-            fit_intercept=False, alpha=alpha, normalize=False, positive=True
+            fit_intercept=False, alpha=alpha, positive=True
         ).fit(X, y)
         clf2 = linear_model.Lasso(
             fit_intercept=False, alpha=alpha, tol=1e-8, positive=True
@@ -663,13 +620,9 @@ def test_lasso_lars_vs_lasso_cd_positive():
         assert error < 0.01
 
 
-@filterwarnings_normalize
 def test_lasso_lars_vs_R_implementation():
     # Test that sklearn LassoLars implementation agrees with the LassoLars
-    # implementation available in R (lars library) under the following
-    # scenarios:
-    # 1) fit_intercept=False and normalize=False
-    # 2) fit_intercept=True and normalize=True
+    # implementation available in R (lars library) when fit_intercept=False.
 
     # Let's generate the data used in the bug report 7778
     y = np.array([-6.45006793, -3.51251449, -8.52445396, 6.12277822, -19.42109366])
@@ -685,11 +638,6 @@ def test_lasso_lars_vs_R_implementation():
 
     X = x.T
 
-    ###########################################################################
-    # Scenario 1: Let's compare R vs sklearn when fit_intercept=False and
-    # normalize=False
-    ###########################################################################
-    #
     # The R result was obtained using the following code:
     #
     # library(lars)
@@ -752,63 +700,13 @@ def test_lasso_lars_vs_R_implementation():
         ]
     )
 
-    model_lasso_lars = linear_model.LassoLars(
-        alpha=0, fit_intercept=False, normalize=False
-    )
+    model_lasso_lars = linear_model.LassoLars(alpha=0, fit_intercept=False)
     model_lasso_lars.fit(X, y)
     skl_betas = model_lasso_lars.coef_path_
 
     assert_array_almost_equal(r, skl_betas, decimal=12)
-    ###########################################################################
-
-    ###########################################################################
-    # Scenario 2: Let's compare R vs sklearn when fit_intercept=True and
-    # normalize=True
-    #
-    # Note: When normalize is equal to True, R returns the coefficients in
-    # their original units, that is, they are rescaled back, whereas sklearn
-    # does not do that, therefore, we need to do this step before comparing
-    # their results.
-    ###########################################################################
-    #
-    # The R result was obtained using the following code:
-    #
-    # library(lars)
-    # model_lasso_lars2 = lars(X, t(y), type="lasso", intercept=TRUE,
-    #                           trace=TRUE, normalize=TRUE)
-    # r2 = t(model_lasso_lars2$beta)
-
-    r2 = np.array(
-        [
-            [0, 0, 0, 0, 0],
-            [0, 0, 0, 8.371887668009453, 19.463768371044026],
-            [0, 0, 0, 0, 9.901611055290553],
-            [
-                0,
-                7.495923132833733,
-                9.245133544334507,
-                17.389369207545062,
-                26.971656815643499,
-            ],
-            [0, 0, -1.569380717440311, -5.924804108067312, -7.996385265061972],
-        ]
-    )
-
-    model_lasso_lars2 = linear_model.LassoLars(alpha=0, normalize=True)
-    model_lasso_lars2.fit(X, y)
-    skl_betas2 = model_lasso_lars2.coef_path_
-
-    # Let's rescale back the coefficients returned by sklearn before comparing
-    # against the R result (read the note above)
-    temp = X - np.mean(X, axis=0)
-    normx = np.sqrt(np.sum(temp**2, axis=0))
-    skl_betas2 /= normx[:, np.newaxis]
-
-    assert_array_almost_equal(r2, skl_betas2, decimal=12)
-    ###########################################################################
 
 
-@filterwarnings_normalize
 @pytest.mark.parametrize("copy_X", [True, False])
 def test_lasso_lars_copyX_behaviour(copy_X):
     """
@@ -825,7 +723,6 @@ def test_lasso_lars_copyX_behaviour(copy_X):
     assert copy_X == np.array_equal(X, X_copy)
 
 
-@filterwarnings_normalize
 @pytest.mark.parametrize("copy_X", [True, False])
 def test_lasso_lars_fit_copyX_behaviour(copy_X):
     """
@@ -841,7 +738,6 @@ def test_lasso_lars_fit_copyX_behaviour(copy_X):
     assert copy_X == np.array_equal(X, X_copy)
 
 
-@filterwarnings_normalize
 @pytest.mark.parametrize("est", (LassoLars(alpha=1e-3), Lars()))
 def test_lars_with_jitter(est):
     # Test that a small amount of jitter helps stability,
@@ -865,7 +761,7 @@ def test_lars_with_jitter(est):
 
 def test_X_none_gram_not_none():
     with pytest.raises(ValueError, match="X cannot be None if Gram is not None"):
-        lars_path(X=None, y=[1], Gram="not None")
+        lars_path(X=None, y=np.array([1]), Gram=True)
 
 
 def test_copy_X_with_auto_gram():
@@ -893,7 +789,6 @@ def test_copy_X_with_auto_gram():
     ),
 )
 @pytest.mark.parametrize("dtype", (np.float32, np.float64))
-@filterwarnings_normalize
 def test_lars_dtype_match(LARS, has_coef_path, args, dtype):
     # The test ensures that the fit method preserves input dtype
     rng = np.random.RandomState(0)
@@ -919,7 +814,6 @@ def test_lars_dtype_match(LARS, has_coef_path, args, dtype):
         (LassoLarsCV, True, {"max_iter": 5}),
     ),
 )
-@filterwarnings_normalize
 def test_lars_numeric_consistency(LARS, has_coef_path, args):
     # The test ensures numerical consistency between trained coefficients
     # of float32 and float64.
@@ -947,9 +841,7 @@ def test_lassolarsic_alpha_selection(criterion):
     (reference [1] in LassoLarsIC) In this example, only 7 features should be
     selected.
     """
-    model = make_pipeline(
-        StandardScaler(), LassoLarsIC(criterion=criterion, normalize=False)
-    )
+    model = make_pipeline(StandardScaler(), LassoLarsIC(criterion=criterion))
     model.fit(X, y)
 
     best_alpha_selected = np.argmin(model[-1].criterion_)
@@ -965,9 +857,7 @@ def test_lassolarsic_noise_variance(fit_intercept):
         n_samples=10, n_features=11 - fit_intercept, random_state=rng
     )
 
-    model = make_pipeline(
-        StandardScaler(), LassoLarsIC(fit_intercept=fit_intercept, normalize=False)
-    )
+    model = make_pipeline(StandardScaler(), LassoLarsIC(fit_intercept=fit_intercept))
 
     err_msg = (
         "You are using LassoLarsIC in the case where the number of samples is smaller"
