@@ -1,45 +1,49 @@
-import numpy as np
-import scipy.sparse as sp
-import pytest
-from numpy.testing import assert_allclose
-
 from re import escape
 
-from sklearn.utils._testing import assert_array_equal
-from sklearn.utils._testing import assert_almost_equal
-from sklearn.utils._mocking import CheckingClassifier
-from sklearn.multiclass import OneVsRestClassifier
-from sklearn.multiclass import OneVsOneClassifier
-from sklearn.multiclass import OutputCodeClassifier
-from sklearn.utils.multiclass import check_classification_targets, type_of_target
+import numpy as np
+import pytest
+import scipy.sparse as sp
+from numpy.testing import assert_allclose
+
+from sklearn import datasets, svm
+from sklearn.datasets import load_breast_cancer
+from sklearn.exceptions import NotFittedError
+from sklearn.impute import SimpleImputer
+from sklearn.linear_model import (
+    ElasticNet,
+    Lasso,
+    LinearRegression,
+    LogisticRegression,
+    Perceptron,
+    Ridge,
+    SGDClassifier,
+)
+from sklearn.metrics import precision_score, recall_score
+from sklearn.model_selection import GridSearchCV, cross_val_score
+from sklearn.multiclass import (
+    OneVsOneClassifier,
+    OneVsRestClassifier,
+    OutputCodeClassifier,
+)
+from sklearn.naive_bayes import MultinomialNB
+from sklearn.neighbors import KNeighborsClassifier
+from sklearn.pipeline import Pipeline, make_pipeline
+from sklearn.svm import SVC, LinearSVC
+from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
 from sklearn.utils import (
     check_array,
     shuffle,
 )
-
-from sklearn.metrics import precision_score
-from sklearn.metrics import recall_score
-
-from sklearn.svm import LinearSVC, SVC
-from sklearn.naive_bayes import MultinomialNB
-from sklearn.linear_model import (
-    LinearRegression,
-    Lasso,
-    ElasticNet,
-    Ridge,
-    Perceptron,
-    LogisticRegression,
-    SGDClassifier,
+from sklearn.utils._mocking import CheckingClassifier
+from sklearn.utils._testing import assert_almost_equal, assert_array_equal
+from sklearn.utils.fixes import (
+    COO_CONTAINERS,
+    CSC_CONTAINERS,
+    CSR_CONTAINERS,
+    DOK_CONTAINERS,
+    LIL_CONTAINERS,
 )
-from sklearn.tree import DecisionTreeClassifier, DecisionTreeRegressor
-from sklearn.neighbors import KNeighborsClassifier
-from sklearn.model_selection import GridSearchCV, cross_val_score
-from sklearn.pipeline import Pipeline, make_pipeline
-from sklearn.impute import SimpleImputer
-from sklearn import svm
-from sklearn.exceptions import NotFittedError
-from sklearn import datasets
-from sklearn.datasets import load_breast_cancer
+from sklearn.utils.multiclass import check_classification_targets, type_of_target
 
 msg = "The default value for `force_alpha` will change"
 pytestmark = pytest.mark.filterwarnings(f"ignore:{msg}:FutureWarning")
@@ -163,52 +167,49 @@ def test_ovr_ovo_regressor():
     assert np.mean(pred == iris.target) > 0.9
 
 
-def test_ovr_fit_predict_sparse():
-    for sparse in [
-        sp.csr_matrix,
-        sp.csc_matrix,
-        sp.coo_matrix,
-        sp.dok_matrix,
-        sp.lil_matrix,
-    ]:
-        base_clf = MultinomialNB(alpha=1)
+@pytest.mark.parametrize(
+    "sparse_container",
+    CSR_CONTAINERS + CSC_CONTAINERS + COO_CONTAINERS + DOK_CONTAINERS + LIL_CONTAINERS,
+)
+def test_ovr_fit_predict_sparse(sparse_container):
+    base_clf = MultinomialNB(alpha=1)
 
-        X, Y = datasets.make_multilabel_classification(
-            n_samples=100,
-            n_features=20,
-            n_classes=5,
-            n_labels=3,
-            length=50,
-            allow_unlabeled=True,
-            random_state=0,
-        )
+    X, Y = datasets.make_multilabel_classification(
+        n_samples=100,
+        n_features=20,
+        n_classes=5,
+        n_labels=3,
+        length=50,
+        allow_unlabeled=True,
+        random_state=0,
+    )
 
-        X_train, Y_train = X[:80], Y[:80]
-        X_test = X[80:]
+    X_train, Y_train = X[:80], Y[:80]
+    X_test = X[80:]
 
-        clf = OneVsRestClassifier(base_clf).fit(X_train, Y_train)
-        Y_pred = clf.predict(X_test)
+    clf = OneVsRestClassifier(base_clf).fit(X_train, Y_train)
+    Y_pred = clf.predict(X_test)
 
-        clf_sprs = OneVsRestClassifier(base_clf).fit(X_train, sparse(Y_train))
-        Y_pred_sprs = clf_sprs.predict(X_test)
+    clf_sprs = OneVsRestClassifier(base_clf).fit(X_train, sparse_container(Y_train))
+    Y_pred_sprs = clf_sprs.predict(X_test)
 
-        assert clf.multilabel_
-        assert sp.issparse(Y_pred_sprs)
-        assert_array_equal(Y_pred_sprs.toarray(), Y_pred)
+    assert clf.multilabel_
+    assert sp.issparse(Y_pred_sprs)
+    assert_array_equal(Y_pred_sprs.toarray(), Y_pred)
 
-        # Test predict_proba
-        Y_proba = clf_sprs.predict_proba(X_test)
+    # Test predict_proba
+    Y_proba = clf_sprs.predict_proba(X_test)
 
-        # predict assigns a label if the probability that the
-        # sample has the label is greater than 0.5.
-        pred = Y_proba > 0.5
-        assert_array_equal(pred, Y_pred_sprs.toarray())
+    # predict assigns a label if the probability that the
+    # sample has the label is greater than 0.5.
+    pred = Y_proba > 0.5
+    assert_array_equal(pred, Y_pred_sprs.toarray())
 
-        # Test decision_function
-        clf = svm.SVC()
-        clf_sprs = OneVsRestClassifier(clf).fit(X_train, sparse(Y_train))
-        dec_pred = (clf_sprs.decision_function(X_test) > 0).astype(int)
-        assert_array_equal(dec_pred, clf_sprs.predict(X_test).toarray())
+    # Test decision_function
+    clf = svm.SVC()
+    clf_sprs = OneVsRestClassifier(clf).fit(X_train, sparse_container(Y_train))
+    dec_pred = (clf_sprs.decision_function(X_test) > 0).astype(int)
+    assert_array_equal(dec_pred, clf_sprs.predict(X_test).toarray())
 
 
 def test_ovr_always_present():
@@ -724,11 +725,12 @@ def test_ecoc_float_y():
         ovo.fit(X, y)
 
 
-def test_ecoc_delegate_sparse_base_estimator():
+@pytest.mark.parametrize("csc_container", CSC_CONTAINERS)
+def test_ecoc_delegate_sparse_base_estimator(csc_container):
     # Non-regression test for
     # https://github.com/scikit-learn/scikit-learn/issues/17218
     X, y = iris.data, iris.target
-    X_sp = sp.csc_matrix(X)
+    X_sp = csc_container(X)
 
     # create an estimator that does not support sparse input
     base_estimator = CheckingClassifier(
@@ -737,11 +739,11 @@ def test_ecoc_delegate_sparse_base_estimator():
     )
     ecoc = OutputCodeClassifier(base_estimator, random_state=0)
 
-    with pytest.raises(TypeError, match="A sparse matrix was passed"):
+    with pytest.raises(TypeError, match="Sparse data was passed"):
         ecoc.fit(X_sp, y)
 
     ecoc.fit(X, y)
-    with pytest.raises(TypeError, match="A sparse matrix was passed"):
+    with pytest.raises(TypeError, match="Sparse data was passed"):
         ecoc.predict(X_sp)
 
     # smoke test to check when sparse input should be supported
@@ -922,3 +924,25 @@ def test_ovo_consistent_binary_classification():
     ovo.fit(X, y)
 
     assert_array_equal(clf.predict(X), ovo.predict(X))
+
+
+def test_multiclass_estimator_attribute_error():
+    """Check that we raise the proper AttributeError when the final estimator
+    does not implement the `partial_fit` method, which is decorated with
+    `available_if`.
+
+    Non-regression test for:
+    https://github.com/scikit-learn/scikit-learn/issues/28108
+    """
+    iris = datasets.load_iris()
+
+    # LogisticRegression does not implement 'partial_fit' and should raise an
+    # AttributeError
+    clf = OneVsRestClassifier(estimator=LogisticRegression(random_state=42))
+
+    outer_msg = "This 'OneVsRestClassifier' has no attribute 'partial_fit'"
+    inner_msg = "'LogisticRegression' object has no attribute 'partial_fit'"
+    with pytest.raises(AttributeError, match=outer_msg) as exec_info:
+        clf.partial_fit(iris.data, iris.target)
+    assert isinstance(exec_info.value.__cause__, AttributeError)
+    assert inner_msg in str(exec_info.value.__cause__)
