@@ -1,7 +1,4 @@
-"""
-The :mod:`sklearn.tree` module includes decision tree-based models for
-classification and regression.
-"""
+"""Decision tree based models for classification and regression."""
 
 from ._classes import (
     BaseDecisionTree,
